Class: Contentful::Management::OrganizationPeriodicUsage Deprecated
- Inherits:
-
Object
- Object
- Contentful::Management::OrganizationPeriodicUsage
- Includes:
- Resource, Resource::Refresher, Resource::SystemProperties
- Defined in:
- lib/contentful/management/organization_periodic_usage.rb
Overview
Backed by the legacy organization_periodic_usages endpoint, which is deprecated in favor of the new Usage API and will be removed on 2027-02-28.
Resource class for OrganizationPeriodicUsage.
Instance Attribute Summary
Attributes included from Resource::SystemProperties
Attributes included from Resource
#client, #properties, #raw_object, #request
Class Method Summary collapse
-
.all(client, organization_id, params = {}) ⇒ Contentful::Management::Array<Contentful::Management::OrganizationPeriodicUsage>
deprecated
Deprecated.
The legacy organization_periodic_usages endpoint is deprecated in favor of the new Usage API and will be removed on 2027-02-28.
-
.create ⇒ Object
Not supported.
-
.find ⇒ Object
Not supported.
Instance Method Summary collapse
-
#destroy ⇒ Object
Not supported.
-
#update ⇒ Object
Not supported.
Methods included from Resource::Refresher
Methods included from Resource
#array?, #default_locale, #environment_id, #fields, #nested_locale_fields?, #resource?, #save, #sys
Class Method Details
.all(client, organization_id, params = {}) ⇒ Contentful::Management::Array<Contentful::Management::OrganizationPeriodicUsage>
The legacy organization_periodic_usages endpoint is deprecated in favor of the new Usage API and will be removed on 2027-02-28.
Gets all organization periodic usages for a given organization.
38 39 40 41 42 43 |
# File 'lib/contentful/management/organization_periodic_usage.rb', line 38 def self.all(client, organization_id, params = {}) warn '[DEPRECATION] `OrganizationPeriodicUsage.all` calls the legacy ' \ 'organization_periodic_usages endpoint, which is deprecated and will be ' \ 'removed on 2027-02-28. Migrate to the new Usage API.' ClientOrganizationPeriodicUsageMethodsFactory.new(client, organization_id).all(params) end |
.create ⇒ Object
Not supported
56 57 58 |
# File 'lib/contentful/management/organization_periodic_usage.rb', line 56 def self.create(*) fail 'Not supported' end |
.find ⇒ Object
Not supported
46 47 48 |
# File 'lib/contentful/management/organization_periodic_usage.rb', line 46 def self.find(*) fail 'Not supported' end |
Instance Method Details
#destroy ⇒ Object
Not supported
61 62 63 |
# File 'lib/contentful/management/organization_periodic_usage.rb', line 61 def destroy fail 'Not supported' end |
#update ⇒ Object
Not supported
66 67 68 |
# File 'lib/contentful/management/organization_periodic_usage.rb', line 66 def update(*) fail 'Not supported' end |